#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dlist-instances
version: 0.1
id: dlist-instances-0.1-90e14b4dd8c3d08d7312806846db20a6
key: dlist_HTmN9eMNEjOBLyGO1t3fdh
license: BSD3
copyright: 2013 Greg Weber
maintainer: Greg Weber <greg@gregweber.info>
homepage: https://github.com/gregwebs/dlist-instances
synopsis: Difference lists instances
description:
    See the dlist packages.
    This package is the canonical source for some orphan instances.
    Orphan instances are placed here to avoid dependencies elsewhere.
category: Data
author: Greg Weber
exposed: True
exposed-modules:
    Data.DList.Instances
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/dlist-instances-0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/dlist-instances-0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/dlist-instances-0.1
hs-libraries: HSdlist-instances-0.1-HTmN9eMNEjOBLyGO1t3fdh
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    dlist-0.7.1.2-60b8202d1ee1445c0a53e803464ea95b
    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
haddock-interfaces: /usr/share/doc/haskell-dlist-instances/html/dlist-instances.haddock
haddock-html: /usr/share/doc/haskell-dlist-instances/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
